import React from 'react';
import ReactDOM from 'react-dom/client';
import Sensor, { sensorLoader, loaderLastValueSensor} from "./routes/sensor";
import Root, { loader as rootLoader } from "./routes/rout";
import ErrorPage from "./error-page";
import {
  createBrowserRouter,
  RouterProvider,
} from "react-router-dom";

function combineLoaders(loaders) {
  return async function combinedLoader(params) {
    const data = {};
    for (const loader of loaders) {
      const result = await loader(params);
      Object.assign(data, result);
    }
    return data;
  }
}
const router = createBrowserRouter([
  {
    path: "/",
    element: <Root/>,
    errorElement: <ErrorPage />,
    loader: rootLoader,
    children: [
      {
        path: "/:sensorName",
        element: <Sensor />,
        loader: combineLoaders([sensorLoader, loaderLastValueSensor]),
      },
    ],
  },
]);

ReactDOM.createRoot(document.getElementById('root')).render(
  <React.StrictMode>
    <RouterProvider router={router} />
  </React.StrictMode>,
)
